Simple test
------------

Ensure your device works with this simple test. For low memory capacity boards

.. literalinclude:: ../examples/dps310_simpletest.py
    :caption: examples/dps310_simpletest.py
    :linenos:

Simple test advanced
------------------------

This is a more advance example that shows the full feature library to use with boards
where memory allows to use it

.. literalinclude:: ../examples/dps310_simpletest_advanced.py
    :caption: examples/dps310_simpletest_advanced.py
    :linenos:


Lower Power Weather Station
---------------------------

Example showing how to configure the sensor for continuous measurement with rates,
sampling counts and mode optimized for low power

.. literalinclude:: ../examples/dps310_low_power_weather_station.py
    :caption: examples/dps310_low_power_weather_station.py
    :linenos:
